/*! \file
 * \brief A FloatingProtectionMessage configures the floating protection for the device.
 *
 * \copyright
 * COPYRIGHT NOTICE: (c) 2021-2022 Neonode Technologies AB. All rights reserved.
 */

#ifndef MESSAGE_FLOATINGPROTECTIONMESSAGE_FLOATINGPROTECTIONMESSAGE_H
#define MESSAGE_FLOATINGPROTECTIONMESSAGE_FLOATINGPROTECTIONMESSAGE_H 1

#ifndef ZFORCECOMMON_H
    #error Please include "zForceCommon.h" before this file.
#endif // ZFORCECOMMON_H

/*!
 * \brief This structure represents a floating protection message.
 *
 * This structure represents a message that configures the floating protection settings.
 */
struct FloatingProtectionMessage
{
    /*!
     * The Message Type of the Message.
     * \n\n
     * Inherited from Message base class.
	 */
    MessageType  MessageType;
    /*!
     * The Message Group of the Message.
     * \n\n
     * Inherited from Message base class.
	 */
    MessageGroup MessageGroup;
    /*!
     * If an error occurred, this is True.
     * \n\n
     * Inherited from Message base class.
	 */
    bool         Error;
    /*!
     * Error Code, valid when Error == true.
     * \n\n
     * Inherited from Message base class.
	 */
    int          ErrorCode;
    /*!
     * Unique serial number for this message.
     * \n\n
     * Inherited from Message base class.
	 */
    uint64_t     SerialNumber;
    /*!
     * Destructor.
     * \n\n
     * Inherited from Message base class.
	 */
    void         ( * Destructor)(Message * self);
    bool         Enabled;    //!< True when Floating Protection is enabled.
    bool         HasEnabled; //!< True when Enabled is valid.
    uint32_t     Time;       //!< Floating Protection time in ms.
    bool         HasTime;    //!< True when Time is valid.
};

#ifdef __cplusplus
extern "C"
{
#endif // __cplusplus

/*!
 * \brief Internal constructor for FloatingProtectionMessage.
 *
 * Internal constructor for FloatingProtectionMessage.
 * Do not use this constructor, always use the factory creator.
 * \n\n
 * On failure, errno is set.
 * - ::EOUTOFMEMORY - Out of memory.
 * - ::EINVALIDSIZE - Invalid size.
 *
 * \param messageGroup MessageGroup of Message.
 * \param size If this is used as a base class for another class, set size to non-zero.
 *
 * \return Pointer to FloatingProtectionMessage.
 */
DLLINTERNAL FloatingProtectionMessage * FloatingProtectionMessage_New (MessageGroup messageGroup, uint32_t size);

#ifdef __cplusplus
}
#endif // __cplusplus

#endif // MESSAGE_FLOATINGPROTECTIONMESSAGE_FLOATINGPROTECTIONMESSAGE_H
