/*! \file
 * \brief A HidDisplaySizeMessage that contains the HID Display Size.
 *
 * \copyright
 * COPYRIGHT NOTICE: (c) 2018-2022 Neonode Technologies AB. All rights reserved.
 */

#ifndef MESSAGE_HIDDISPLAYSIZEMESSAGE_HIDDISPLAYSIZEMESSAGE_H
#define MESSAGE_HIDDISPLAYSIZEMESSAGE_HIDDISPLAYSIZEMESSAGE_H 1

#ifndef ZFORCECOMMON_H
    #error Please include "zForceCommon.h" before this file.
#endif // ZFORCECOMMON_H

/*!
 * \brief This structure represents a HID Display Size Message.
 *
 * This structure represents a message containing the HID Display Size.
 */
struct HidDisplaySizeMessage
{
    /*!
     * The Message Type of the Message.
     * \n\n
     * Inherited from Message base class.
	 */
    MessageType  MessageType;
    /*!
     * The Message Group of the Message.
     * \n\n
     * Inherited from Message base class.
	 */
    MessageGroup MessageGroup;
    /*!
     * If an error occurred, this is True.
     * \n\n
     * Inherited from Message base class.
	 */
    bool         Error;
    /*!
     * Error Code, valid when Error == true.
     * \n\n
     * Inherited from Message base class.
	 */
    int          ErrorCode;
    /*!
     * Unique serial number for this message.
     * \n\n
     * Inherited from Message base class.
	 */
    uint64_t     SerialNumber;
    /*!
     * Destructor.
     * \n\n
     * Inherited from Message base class.
	 */
    void         ( * Destructor) (Message * self);
    uint32_t     SizeX;    //!< X Size.
    bool         HasSizeX; //!< True when SizeX is valid.
    uint32_t     SizeY;    //!< Y Size.
    bool         HasSizeY; //!< True when SizeY is valid.
};

#ifdef __cplusplus
extern "C"
{
#endif // __cplusplus

/*!
 * \brief Internal constructor for HidDisplaySizeMessage.
 *
 * Internal constructor for HidDisplaySizeMessage.
 * Do not use this constructor, always use the factory creator.
 * \n\n
 * On failure, errno is set.
 * - ::EOUTOFMEMORY - Out of memory.
 * - ::EINVALIDSIZE - Invalid size.
 *
 * \param messageGroup MessageGroup of Message.
 * \param size If this is used as a base class for another class, set size to non-zero.
 *
 * \return Pointer to HidDisplaySizeMessage.
 */
DLLINTERNAL HidDisplaySizeMessage * HidDisplaySizeMessage_New (MessageGroup messageGroup, uint32_t size);

#ifdef __cplusplus
}
#endif // __cplusplus

#endif // MESSAGE_HIDDISPLAYSIZEMESSAGE_HIDDISPLAYSIZEMESSAGE_H
