/*! \file
 * \brief An McuUniqueIdentifierMessage that contains the MCU Unique Identifier.
 *
 * \copyright
 * COPYRIGHT NOTICE: (c) 2017-2022 Neonode Technologies AB. All rights reserved.
 */

#ifndef MESSAGE_MCUUNIQUEIDENTIFIERMESSAGE_MCUUNIQUEIDENTIFIERMESSAGE_H
#define MESSAGE_MCUUNIQUEIDENTIFIERMESSAGE_MCUUNIQUEIDENTIFIERMESSAGE_H 1

#ifndef ZFORCECOMMON_H
    #error Please include "zForceCommon.h" before this file.
#endif // ZFORCECOMMON_H

 /*!
 * \brief This structure represents an mcu unique identifier message.
 *
 * This structure represents a message which contains the unique mcu identifier of a platform.
 */
struct McuUniqueIdentifierMessage
{
    /*!
     * The Message Type of the Message.
     * \n\n
     * Inherited from Message base class.
	 */
    MessageType  MessageType;
    /*!
     * The Message Group of the Message.
     * \n\n
     * Inherited from Message base class.
	 */
    MessageGroup MessageGroup;
    /*!
     * If an error occurred, this is True.
     * \n\n
     * Inherited from Message base class.
	 */
    bool         Error;
    /*!
     * Error Code, valid when Error == true.
     * \n\n
     * Inherited from Message base class.
	 */
    int          ErrorCode;
    /*!
     * Unique serial number for this message.
     * \n\n
     * Inherited from Message base class.
	 */
    uint64_t     SerialNumber;
    /*!
     * Destructor.
     * \n\n
     * Inherited from Message base class.
	 */
    void         ( * Destructor)(Message * self);
    uint8_t    * McuUniqueIdentifier; //!< MCU identifier.
    uint32_t     BufferSize;          //!< Size of mcu identifier.
};

#ifdef __cplusplus
extern "C"
{
#endif // __cplusplus

/*!
 * \brief Internal constructor for McuUniqueIdentifierMessage.
 *
 * Internal constructor for McuUniqueIdentifierMessage.
 * Do not use this constructor, always use the factory creator.
 * \n\n
 * On failure, errno is set.
 * - ::EOUTOFMEMORY - Out of memory.
 * - ::EINVALIDSIZE - Invalid size.
 *
 * \param messageGroup MessageGroup of Message.
 * \param size If this is used as a base class for another class, set size to non-zero.
 *
 * \return Pointer to McuUniqueIdentifierMessage.
 */
DLLINTERNAL McuUniqueIdentifierMessage * McuUniqueIdentifierMessage_New (MessageGroup messageGroup, uint32_t size);

#ifdef __cplusplus
}
#endif // __cplusplus

#endif // MESSAGE_MCUUNIQUEIDENTIFIERMESSAGE_MCUUNIQUEIDENTIFIERMESSAGE_H
