/*! \file
 * \brief A NumberOfTrackedObjectsMessage containing how many objects are tracked at once.
 *
 * \copyright
 * COPYRIGHT NOTICE: (c) 2017-2022 Neonode Technologies AB. All rights reserved.
 */

#ifndef MESSAGE_NUMBEROFTRACKEDOBJECTSMESSAGE_NUMBEROFTRACKEDOBJECTSMESSAGE_H
#define MESSAGE_NUMBEROFTRACKEDOBJECTSMESSAGE_NUMBEROFTRACKEDOBJECTSMESSAGE_H 1

#ifndef ZFORCECOMMON_H
    #error Please include "zForceCommon.h" before this file.
#endif // ZFORCECOMMON_H

/*!
 * \brief This structure represents a number of tracked objects message.
 *
 * This structure represents a message which indicates the number of objects to be tracked by a device.
 */
struct NumberOfTrackedObjectsMessage
{
    /*!
     * The Message Type of the Message.
     * \n\n
     * Inherited from Message base class.
	 */
    MessageType  MessageType;
    /*!
     * The Message Group of the Message.
     * \n\n
     * Inherited from Message base class.
	 */
    MessageGroup MessageGroup;
    /*!
     * If an error occurred, this is True.
     * \n\n
     * Inherited from Message base class.
	 */
    bool         Error;
    /*!
     * Error Code, valid when Error == true.
     * \n\n
     * Inherited from Message base class.
	 */
    int          ErrorCode;
    /*!
     * Unique serial number for this message.
     * \n\n
     * Inherited from Message base class.
	 */
    uint64_t     SerialNumber;
    /*!
     * Destructor.
     * \n\n
     * Inherited from Message base class.
	 */
    void         ( * Destructor)(Message * self);
    uint32_t     NumberOfTrackedObjects; //!< Tracked objects count.
};

#ifdef __cplusplus
extern "C"
{
#endif // __cplusplus

/*!
 * \brief Internal constructor for NumberOfTrackedObjectsMessage.
 *
 * Internal constructor for NumberOfTrackedObjectsMessage.
 * Do not use this constructor, always use the factory creator.
 * \n\n
 * On failure, errno is set.
 * - ::EOUTOFMEMORY - Out of memory.
 * - ::EINVALIDSIZE - Invalid size.
 *
 * \param messageGroup MessageGroup of Message.
 * \param size If this is used as a base class for another class, set size to non-zero.
 *
 * \return Pointer to NumberOfTrackedObjectsMessage.
 */
DLLINTERNAL NumberOfTrackedObjectsMessage * NumberOfTrackedObjectsMessage_New (MessageGroup messageGroup,
                                                                               uint32_t size);

#ifdef __cplusplus
}
#endif // __cplusplus

#endif // MESSAGE_NUMBEROFTRACKEDOBJECTSMESSAGE_NUMBEROFTRACKEDOBJECTSMESSAGE_H
