/*! \file
 * \brief An OffsetMessage that contains the Offset a Device is set to.
 *
 * \copyright
 * COPYRIGHT NOTICE: (c) 2018-2022 Neonode Technologies AB. All rights reserved.
 */

#ifndef MESSAGE_OFFSETMESSAGE_OFFSETMESSAGE_H
#define MESSAGE_OFFSETMESSAGE_OFFSETMESSAGE_H 1

#ifndef ZFORCECOMMON_H
    #error Please include "zForceCommon.h" before this file.
#endif // ZFORCECOMMON_H

/*!
 * \brief This structure represents an offset message.
 *
 * This structure represents a message containing offset information.
 */
struct OffsetMessage
{
    /*!
     * The Message Type of the Message.
     * \n\n
     * Inherited from Message base class.
	 */
    MessageType  MessageType;
    /*!
     * The Message Group of the Message.
     * \n\n
     * Inherited from Message base class.
	 */
    MessageGroup MessageGroup;
    /*!
     * If an error occurred, this is True.
     * \n\n
     * Inherited from Message base class.
	 */
    bool         Error;
    /*!
     * Error Code, valid when Error == true.
     * \n\n
     * Inherited from Message base class.
	 */
    int          ErrorCode;
    /*!
     * Unique serial number for this message.
     * \n\n
     * Inherited from Message base class.
	 */
    uint64_t     SerialNumber;
    /*!
     * Destructor.
     * \n\n
     * Inherited from Message base class.
	 */
    void         ( * Destructor)(Message * self);
    uint32_t     OffsetX;    //!< X Offset.
    bool         HasOffsetX; //!< True when OffsetX is valid.
    uint32_t     OffsetY;    //!< Y Offset.
    bool         HasOffsetY; //!< True when OffsetY is valid.
};

#ifdef __cplusplus
extern "C"
{
#endif // __cplusplus

/*!
 * \brief Internal constructor for OffsetMessage.
 *
 * Internal constructor for OffsetMessage.
 * Do not use this constructor, always use the factory creator.
 * \n\n
 * On failure, errno is set.
 * - ::EOUTOFMEMORY - Out of memory.
 * - ::EINVALIDSIZE - Invalid size.
 *
 * \param messageGroup MessageGroup of Message.
 * \param size If this is used as a base class for another class, set size to non-zero.
 *
 * \return Pointer to OffsetMessage.
 */
DLLINTERNAL OffsetMessage * OffsetMessage_New (MessageGroup messageGroup, uint32_t size);

#ifdef __cplusplus
}
#endif // __cplusplus

#endif // MESSAGE_OFFSETMESSAGE_OFFSETMESSAGE_H
