/*! \file
 * \brief An OperationModesMessage contains the modes the Device is set to.
 *
 * \copyright
 * COPYRIGHT NOTICE: (c) 2017-2022 Neonode Technologies AB. All rights reserved.
 */

#ifndef MESSAGE_OPERATIONMODESMESSAGE_OPERATIONMODESMESSAGE_H
#define MESSAGE_OPERATIONMODESMESSAGE_OPERATIONMODESMESSAGE_H 1

#ifndef ZFORCECOMMON_H
    #error Please include "zForceCommon.h" before this file.
#endif // ZFORCECOMMON_H

/*!
 * \brief This structure represents a operation mode message.
 *
 * This structure represents a message containing operation mode information.
 * The operating modes of the Device is described by two bitmasks.
 * The Mask contains which modes were changed and Values contains what value
 * they were set to.
 */
struct OperationModesMessage
{
    /*!
     * The Message Type of the Message.
     * \n\n
     * Inherited from Message base class.
	 */
    MessageType    MessageType;
    /*!
     * The Message Group of the Message.
     * \n\n
     * Inherited from Message base class.
	 */
    MessageGroup   MessageGroup;
    /*!
     * If an error occurred, this is True.
     * \n\n
     * Inherited from Message base class.
	 */
    bool           Error;
    /*!
     * Error Code, valid when Error == true.
     * \n\n
     * Inherited from Message base class.
	 */
    int            ErrorCode;
    /*!
     * Unique serial number for this message.
     * \n\n
     * Inherited from Message base class.
	 */
    uint64_t       SerialNumber;
    /*!
     * Destructor.
     * \n\n
     * Inherited from Message base class.
	 */
    void           ( * Destructor)(Message * self);
    OperationModes Mask;   //!< Mode Mask.
    OperationModes Values; //!< Mode Values.
};

#ifdef __cplusplus
extern "C"
{
#endif // __cplusplus

/*!
 * \brief Internal constructor for OperationModesMessage.
 *
 * Internal constructor for OperationModesMessage.
 * Do not use this constructor, always use the factory creator.
 * \n\n
 * On failure, errno is set.
 * - ::EOUTOFMEMORY - Out of memory.
 * - ::EINVALIDSIZE - Invalid size.
 *
 * \param messageGroup MessageGroup of Message.
 * \param size If this is used as a base class for another class, set size to non-zero.
 *
 * \return Pointer to OperationModesMessage.
 */
DLLINTERNAL OperationModesMessage * OperationModesMessage_New (MessageGroup messageGroup, uint32_t size);

#ifdef __cplusplus
}
#endif // __cplusplus

#endif // MESSAGE_OPERATIONMODESMESSAGE_OPERATIONMODESMESSAGE_H
