/*! \file
 * \brief A ReflectiveEdgeFilterMessage contains the modes the Device is set to.
 *
 * \copyright
 * COPYRIGHT NOTICE: (c) 2018-2022 Neonode Technologies AB. All rights reserved.
 */

#ifndef MESSAGE_REFLECTIVEEDGEFILTERMESSAGE_REFLECTIVEEDGEFILTERMESSAGE_H
#define MESSAGE_REFLECTIVEEDGEFILTERMESSAGE_REFLECTIVEEDGEFILTERMESSAGE_H 1

#ifndef ZFORCECOMMON_H
    #error Please include "zForceCommon.h" before this file.
#endif // ZFORCECOMMON_H

/*!
 * \brief This structure represents a operation mode message.
 *
 * This structure represents a message that turns on a filter that
 * reduces the chance of ghost touches if there is highly reflective
 * surface outside of the touch active area.
 */
struct ReflectiveEdgeFilterMessage
{
    /*!
     * The Message Type of the Message.
     * \n\n
     * Inherited from Message base class.
	 */
    MessageType  MessageType;
    /*!
     * The Message Group of the Message.
     * \n\n
     * Inherited from Message base class.
	 */
    MessageGroup MessageGroup;
    /*!
     * If an error occurred, this is True.
     * \n\n
     * Inherited from Message base class.
	 */
    bool         Error;
    /*!
     * Error Code, valid when Error == true.
     * \n\n
     * Inherited from Message base class.
	 */
    int          ErrorCode;
    /*!
     * Unique serial number for this message.
     * \n\n
     * Inherited from Message base class.
	 */
    uint64_t     SerialNumber;
    /*!
     * Destructor.
     * \n\n
     * Inherited from Message base class.
	 */
    void         ( * Destructor)(Message * self);
    bool         FilterIsOn; //!< True when the filter is enabled.
};

#ifdef __cplusplus
extern "C"
{
#endif // __cplusplus

/*!
 * \brief Internal constructor for ReflectiveEdgeFilterMessage.
 *
 * Internal constructor for ReflectiveEdgeFilterMessage.
 * Do not use this constructor, always use the factory creator.
 * \n\n
 * On failure, errno is set.
 * - ::EOUTOFMEMORY - Out of memory.
 * - ::EINVALIDSIZE - Invalid size.
 *
 * \param messageGroup MessageGroup of Message.
 * \param size If this is used as a base class for another class, set size to non-zero.
 *
 * \return Pointer to ReflectiveEdgeFilterMessage.
 */
DLLINTERNAL ReflectiveEdgeFilterMessage * ReflectiveEdgeFilterMessage_New (MessageGroup messageGroup, uint32_t size);

#ifdef __cplusplus
}
#endif // __cplusplus

#endif // MESSAGE_REFLECTIVEEDGEFILTERMESSAGE_REFLECTIVEEDGEFILTERMESSAGE_H
