/*! \file
 * \brief A ReverseTouchActiveAreaMessage contains the Touch Active Area of a Device.
 *
 * \copyright
 * COPYRIGHT NOTICE: (c) 2018-2022 Neonode Technologies AB. All rights reserved.
 */

#ifndef MESSAGE_REVERSETOUCHACTIVEAREAMESSAGE_REVERSETOUCHACTIVEAREAMESSAGE_H
#define MESSAGE_REVERSETOUCHACTIVEAREAMESSAGE_REVERSETOUCHACTIVEAREAMESSAGE_H 1

#ifndef ZFORCECOMMON_H
    #error Please include "zForceCommon.h" before this file.
#endif // ZFORCECOMMON_H

/*!
 * \brief This structure represents a reverse touch active area message.
 *
 * This structure represents a message which indicates what reverse touch active area
 * a device uses.
 */
struct ReverseTouchActiveAreaMessage
{
    /*!
     * The Message Type of the Message.
     * \n\n
     * Inherited from Message base class.
	 */
    MessageType  MessageType;
    /*!
     * The Message Group of the Message.
     * \n\n
     * Inherited from Message base class.
	 */
    MessageGroup MessageGroup;
    /*!
     * If an error occurred, this is True.
     * \n\n
     * Inherited from Message base class.
	 */
    bool         Error;
    /*!
     * Error Code, valid when Error == true.
     * \n\n
     * Inherited from Message base class.
	 */
    int          ErrorCode;
    /*!
     * Unique serial number for this message.
     * \n\n
     * Inherited from Message base class.
	 */
    uint64_t     SerialNumber;
    /*!
     * Destructor.
     * \n\n
     * Inherited from Message base class.
	 */
    void         ( * Destructor)(Message * self);
    bool         XIsReversed;   //!< True if the X axis is reversed.
    bool         YIsReversed;   //!< True if the Y axis is reversed.
};

#ifdef __cplusplus
extern "C"
{
#endif // __cplusplus

/*!
 * \brief Internal constructor for ReverseTouchActiveAreaMessage.
 *
 * Internal constructor for ReverseTouchActiveAreaMessage.
 * Do not use this constructor, always use the factory creator.
 * \n\n
 * On failure, errno is set.
 * - ::EOUTOFMEMORY - Out of memory.
 * - ::EINVALIDSIZE - Invalid size.
 *
 * \param messageGroup MessageGroup of Message.
 * \param size If this is used as a base class for another class, set size to non-zero.
 *
 * \return Pointer to ReverseTouchActiveAreaMessage.
 */
DLLINTERNAL ReverseTouchActiveAreaMessage * ReverseTouchActiveAreaMessage_New (MessageGroup messageGroup, uint32_t size);

#ifdef __cplusplus
}
#endif // __cplusplus

#endif // MESSAGE_REVERSETOUCHACTIVEAREAMESSAGE_REVERSETOUCHACTIVEAREAMESSAGE_H
