/*! \file
 * \brief A TouchActiveAreaMessage contains the Touch Active Area of a Device.
 *
 * \copyright
 * COPYRIGHT NOTICE: (c) 2017-2022 Neonode Technologies AB. All rights reserved.
 */

#ifndef MESSAGE_TOUCHACTIVEAREAMESSAGE_TOUCHACTIVEAREAMESSAGE_H
#define MESSAGE_TOUCHACTIVEAREAMESSAGE_TOUCHACTIVEAREAMESSAGE_H 1

#ifndef ZFORCECOMMON_H
    #error Please include "zForceCommon.h" before this file.
#endif // ZFORCECOMMON_H

/*!
 * \brief This structure represents a touch active area message.
 *
 * This structure represents a message which indicates what touch active area
 * a device uses.
 */
struct TouchActiveAreaMessage
{
    /*!
     * The Message Type of the Message.
     * \n\n
     * Inherited from Message base class.
	 */
    MessageType  MessageType;
    /*!
     * The Message Group of the Message.
     * \n\n
     * Inherited from Message base class.
	 */
    MessageGroup MessageGroup;
    /*!
     * If an error occurred, this is True.
     * \n\n
     * Inherited from Message base class.
	 */
    bool         Error;
    /*!
     * Error Code, valid when Error == true.
     * \n\n
     * Inherited from Message base class.
	 */
    int          ErrorCode;
    /*!
     * Unique serial number for this message.
     * \n\n
     * Inherited from Message base class.
	 */
    uint64_t     SerialNumber;
    /*!
     * Destructor.
     * \n\n
     * Inherited from Message base class.
	 */
    void         ( * Destructor)(Message * self);
    uint32_t     LowerBoundX; //!< Start of the Touch Active Area X axis.
    uint32_t     UpperBoundX; //!< End of the Touch Active Area X axis.
    bool         HasX;        //!< True when LowerBoundX and UpperBoundX are valid.
    uint32_t     LowerBoundY; //!< Start of the Touch Active Area Y axis.
    uint32_t     UpperBoundY; //!< End of the Touch Active Area Y axis.
    bool         HasY;        //!< True when LowerBoundY and UpperBoundY are valid.
};

#ifdef __cplusplus
extern "C"
{
#endif // __cplusplus

/*!
 * \brief Internal constructor for TouchActiveAreaMessage.
 *
 * Internal constructor for TouchActiveAreaMessage.
 * Do not use this constructor, always use the factory creator.
 * \n\n
 * On failure, errno is set.
 * - ::EOUTOFMEMORY - Out of memory.
 * - ::EINVALIDSIZE - Invalid size.
 *
 * \param messageGroup MessageGroup of Message.
 * \param size If this is used as a base class for another class, set size to non-zero.
 *
 * \return Pointer to TouchActiveAreaMessage.
 */

DLLINTERNAL TouchActiveAreaMessage * TouchActiveAreaMessage_New (MessageGroup messageGroup, uint32_t size);

#ifdef __cplusplus
}
#endif // __cplusplus

#endif // MESSAGE_TOUCHACTIVEAREAMESSAGE_TOUCHACTIVEAREAMESSAGE_H
